<?php
/**
 * Created by PhpStorm.
 * User: robin
 * Date: 7/2/16
 * Time: 9:45 PM
 */

namespace Luticate\Auth\Controller;

use Luticate\Auth\Business\LuUsersBusiness;
use Luticate\Auth\Dbo\Users\LuUsersDbo;
use Luticate\Auth\Dbo\Users\LuUsersEditDbo;
use Luticate\Auth\Dbo\Users\LuUsersLiteDbo;
use Luticate\Auth\Dbo\Users\LuUsersLoginDbo;
use Luticate\Auth\Dbo\Users\LuUsersLoginResultDbo;
use Luticate\Auth\Dbo\Users\LuUsersAddDbo;
use Luticate\Utils\Controller\LuController;
use Luticate\Utils\Dbo\LuQueryDbo;

class LuUsersController extends LuController
{
    public function getBusiness()
    {
        return new LuUsersBusiness();
    }

    /**
     * Login the user
     * @param $login LuUsersLoginDbo The user authentication data
     * @return LuUsersLoginResultDbo
     */
    public function login(LuUsersLoginDbo $login)
    {
        return static::getBusiness()->login($login);
    }

    /**
     * Logout the logged user. All tokens will be revoked
     * @param $_user LuUsersDbo The logged user
     * @return bool
     */
    public function logout(LuUsersDbo $_user)
    {
        return static::getBusiness()->logout($_user);
    }

    /**
     * Get the logged user
     * @param $_user LuUsersDbo The user id
     * @return LuUsersLiteDbo
     */
    public function getMe(LuUsersDbo $_user)
    {
        return static::getBusiness()->getSingleLiteById($_user->getId());
    }

    /**
     * Get a user by its id
     * @param $userId int The user id
     * @return LuUsersLiteDbo
     */
    public function getById(int $userId)
    {
        return static::getBusiness()->getSingleLiteById($userId);
    }

    /**
     * Get all users
     * @param LuQueryDbo $query The filter query
     * @return LuUsersLiteDbo[]
     */
    public function getAll(LuQueryDbo $query)
    {
        return static::getBusiness()->getAllLite($query);
    }

    /**
     * Add a new user
     * @param LuUsersAddDbo $user The new user
     * @return LuUsersLiteDbo
     */
    public function add(LuUsersAddDbo $user)
    {
        return static::getBusiness()->add($user);
    }

    /**
     * Delete a user by its id
     * @param $userId int The user id
     * @return LuUsersDbo
     */
    public function del(int $userId)
    {
        return static::getBusiness()->del($userId);
    }

    /**
     * Edit a user by its id
     * @param int $userId The user id
     * @param LuUsersEditDbo $user The edited user
     * @return LuUsersDbo
     */
    public function edit(int $userId, LuUsersEditDbo $user)
    {
        return static::getBusiness()->edit($userId, $user);
    }

    /**
     * Edit the logged user
     * @param LuUsersDbo $_user The logged user
     * @param LuUsersEditDbo $user The edited user
     * @return LuUsersDbo
     */
    public function editMe(LuUsersDbo $_user, LuUsersEditDbo $user)
    {
        return static::getBusiness()->edit($_user->getId(), $user);
    }

    /**
     * Set the user's password by its id
     * @param int $userId The user id
     * @param string $password Ths new user password
     * @return bool
     */
    public function setPassword(int $userId, string $password)
    {
        return static::getBusiness()->setPassword($userId, $password);
    }

    /**
     * Set the logged user's password
     * @param LuUsersDbo $_user The logged user
     * @param string $password The new user password
     * @param string $oldPassword The current user password
     * @return bool
     */
    public function setPasswordMe(LuUsersDbo $_user, string $password, string $oldPassword)
    {
        return static::getBusiness()->setPasswordMe($_user, $password, $oldPassword);
    }
}